box.evaluate.core: Box Plots

View source: R/box.evaluate.core.R

box.evaluate.coreR Documentation

Box Plots

Description

Plot Box-and-Whisker plots \insertCitetukey_exploratory_1970,mcgill_variations_1978EvaluateCore to graphically compare the probability distributions of quantitative traits between entire collection (EC) and core set (CS).

Usage

box.evaluate.core(data, names, quantitative, selected, show.count = FALSE)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

show.count

logical. If TRUE, the accession count excluding missing values will also be displayed. Default is FALSE.

Value

A list with the ggplot objects of box plots of CS and EC for each trait specified as quantitative.

References

\insertAllCited

See Also

boxplot, geom_boxplot

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))


box.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core)

box.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core, show.count = TRUE)



EvaluateCore documentation built on April 22, 2026, 9:07 a.m.