coverage.evaluate.core: Class Coverage

View source: R/coverage.evaluate.core.R

coverage.evaluate.coreR Documentation

Class Coverage

Description

Compute the Class Coverage \insertCitekim_PowerCore_2007EvaluateCore to compare the distribution frequencies of qualitative traits between entire collection (EC) and core set (CS).

Usage

coverage.evaluate.core(data, names, qualitative, selected, na.omit = TRUE)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

qualitative

Name of columns with the qualitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

na.omit

logical. If TRUE, missing values (NA) are ignored and not included as a distinct factor level for analysis. Default is TRUE.

Details

Class Coverage \insertCitekim_PowerCore_2007EvaluateCore is computed as follows.

\mjsdeqn

Class\, Coverage = \left ( \frac1n \sum_i=1^n \frack_CS_ik_EC_i \right ) \times 100

Where, \mjseqnk_CS_i is the number of phenotypic classes in CS for the \mjseqnith trait, \mjseqnk_EC_i is the number of phenotypic classes in EC for the \mjseqnith trait and \mjseqnn is the total number of traits.

Value

The Class Coverage value.

References

\insertAllCited

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

coverage.evaluate.core(data = ec, names = "genotypes",
                       qualitative = qual, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.