cr.evaluate.core: Coincidence Rate of Range

View source: R/cr.evaluate.core.R

cr.evaluate.coreR Documentation

Coincidence Rate of Range

Description

Compute the following metrics to compare quantitative traits of the entire collection (EC) and core set (CS).

  • Coincidence Rate of Range (\mjseqnCR) \insertCitehu_methods_2000EvaluateCore (originally described by \insertCitediwan_methods_1995EvaluateCore as Mean range ratio)

  • Changeable Rate of Maximum (\mjseqnCR_\max) \insertCitewang_assessment_2007EvaluateCore

  • Changeable Rate of Minimum (\mjseqnCR_\min) \insertCitewang_assessment_2007EvaluateCore

  • Changeable Rate of Mean (\mjseqnCR_\mu) \insertCitewang_assessment_2007EvaluateCore

Usage

cr.evaluate.core(data, names, quantitative, selected)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

Details

The Coincidence Rate of Range (\mjseqnCR) is computed as follows.

\mjsdeqn

CR = \left ( \frac1n \sum_i=1^n \fracR_CS_iR_EC_i \right ) \times 100

Where, \mjseqnR_CS_i is the range of the \mjseqnith trait in the CS, \mjseqnR_EC_i is the range of the \mjseqnith trait in the EC and \mjseqnn is the total number of traits.

A representative CS should have a \mjseqnCR value no less than 70% \insertCitediwan_methods_1995EvaluateCore or 80% \insertCitehu_methods_2000EvaluateCore.

The Changeable Rate of Maximum (\mjseqnCR_\max) is computed as follows.

\mjsdeqn

CR_\max = \left ( \frac1n \sum_i=1^n \frac\max_CS_i\max_EC_i \right ) \times 100

Where, \mjseqn\max_CS_i is the maximum value of the \mjseqnith trait in the CS, \mjseqn\max_EC_i is the maximum value of the \mjseqnith trait in the EC and \mjseqnn is the total number of traits.

The Changeable Rate of Minimum (\mjseqnCR_\min) is computed as follows.

\mjsdeqn

CR_\min = \left ( \frac1n \sum_i=1^n \frac\min_CS_i\min_EC_i \right ) \times 100

Where, \mjseqn\min_CS_i is the minimum value of the \mjseqnith trait in the CS, \mjseqn\min_EC_i is the minimum value of the \mjseqnith trait in the EC and \mjseqnn is the total number of traits.

The Changeable Rate of Mean (\mjseqnCR_\mu) is computed as follows.

\mjsdeqn

CR_\mu = \left ( \frac1n \sum_i=1^n \frac\mu_CS_i\mu_EC_i \right ) \times 100

Where, \mjseqn\mu_CS_i is the mean value of the \mjseqnith trait in the CS, \mjseqn\mu_EC_i is the mean value of the \mjseqnith trait in the EC and \mjseqnn is the total number of traits.

Value

The \mjseqnCR value.

Note

NaN or Inf values for \mjseqnCR_\min occurs when the minimum values for some of the traits are zero.

References

\insertAllCited

See Also

wilcox.test

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

cr.evaluate.core(data = ec, names = "genotypes",
                 quantitative = quant, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.