iqr.evaluate.core: Interquartile Range

View source: R/iqr.evaluate.core.R

iqr.evaluate.coreR Documentation

Interquartile Range

Description

Compute the Interquartile Range (IQR) \insertCiteupton_general_1996EvaluateCore to compare quantitative traits of the entire collection (EC) and core set (CS).

Usage

iqr.evaluate.core(data, names, quantitative, selected)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

Value

A data frame with the accession count (excluding missing data) as well as the IQR values of the EC and CS for the traits specified as quantitative.

References

\insertAllCited

See Also

IQR

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

iqr.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.