percentdiff.evaluate.core: Percentage Difference of Means and Variances

View source: R/percentdiff.evaluate.core.R

percentdiff.evaluate.coreR Documentation

Percentage Difference of Means and Variances

Description

Compute the following differences between the entire collection (EC) and core set (CS).

  • Percentage of significant differences of mean (\mjteqnMD\%_HuMD\\\%_HuMD%_Hu) \insertCitehu_methods_2000EvaluateCore

  • Percentage of significant differences of variance (\mjteqnVD\%_HuVD\\\%_HuVD%_Hu) \insertCitehu_methods_2000EvaluateCore

  • Average of absolute differences between means (\mjteqnMD\%_KimMD\\\%_KimMD%_Kim) \insertCitekim_PowerCore_2007EvaluateCore

  • Average of absolute differences between variances (\mjteqnVD\%_KimVD\\\%_KimVD%_Kim) \insertCitekim_PowerCore_2007EvaluateCore

  • Percentage difference between the mean squared Euclidean distance among accessions (\mjteqn\overlinedD\%\overlinedD\\\%\overlinedD%) \insertCitestudnicki_comparing_2013EvaluateCore

  • Percentage of range ratios smaller than 0.70 (\mjseqnS_RR_0.7) \insertCitediwan_methods_1995EvaluateCore

Usage

percentdiff.evaluate.core(
  data,
  names,
  quantitative,
  selected,
  alpha = 0.05,
  rr.crit = 0.7
)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

alpha

Type I error probability (Significance level) of difference.

rr.crit

The critical value of range ratio considered to be acceptable for a representative CS. The default value is 0.7.

Details

The differences are computed as follows.

\mjtdeqn

MD\%_Hu = \left ( \fracS_tn \right ) \times 100MD\\\%_Hu = \left ( \fracS_tn \right ) \times 100MD%_Hu = \left ( \fracS_tn \right ) \times 100

Where, \mjseqnS_t is the number of traits with a significant difference between the means of the EC and the CS and \mjseqnn is the total number of traits. A representative core should have \mjteqnMD\%_HuMD\\\%_HuMD%_Hu < 20 % and \mjseqnCR > 80 % \insertCitehu_methods_2000EvaluateCore.

\mjtdeqn

VD\%_Hu = \left ( \fracS_Fn \right ) \times 100VD\\\%_Hu = \left ( \fracS_Fn \right ) \times 100VD%_Hu = \left ( \fracS_Fn \right ) \times 100

Where, \mjseqnS_F is the number of traits with a significant difference between the variances of the EC and the CS and \mjseqnn is the total number of traits. Larger \mjteqnVD\%_HuVD\\\%_HuVD%_Hu value indicates a more diverse core set.

\mjtdeqn

MD\%_Kim = \left ( \frac1n\sum_i=1^n \frac\left | M_EC_i-M_CS_i \right |M_CS_i \right ) \times 100MD\\\%_Kim = \left ( \frac1n\sum_i=1^n \frac\left | M_EC_i-M_CS_i \right |M_CS_i \right ) \times 100MD%_Kim = \left ( \frac1n\sum_i=1^n \frac\left | M_EC_i-M_CS_i \right |M_CS_i \right ) \times 100

Where, \mjseqnM_EC_i is the mean of the EC for the \mjseqnith trait, \mjseqnM_CS_i is the mean of the CS for the \mjseqnith trait and \mjseqnn is the total number of traits.

\mjtdeqn

VD\%_Kim = \left ( \frac1n\sum_i=1^n \frac\left | V_EC_i-V_CS_i \right |V_CS_i \right ) \times 100VD\\\%_Kim = \left ( \frac1n\sum_i=1^n \frac\left | V_EC_i-V_CS_i \right |V_CS_i \right ) \times 100VD%_Kim = \left ( \frac1n\sum_i=1^n \frac\left | V_EC_i-V_CS_i \right |V_CS_i \right ) \times 100

Where, \mjseqnV_EC_i is the variance of the EC for the \mjseqnith trait, \mjseqnV_CS_i is the variance of the CS for the \mjseqnith trait and \mjseqnn is the total number of traits.

\mjtdeqn\overline

dD\% = \frac\overlined_CS-\overlined_EC\overlined_EC \times 100\overlinedD\\\% = \frac\overlined_CS-\overlined_EC\overlined_EC \times 100\overlinedD\ \frac\overlined_CS-\overlined_EC\overlined_EC \times 100

Where, \mjseqn\overlined_CS is the mean squared Euclidean distance among accessions in the CS and \mjseqn\overlined_EC is the mean squared Euclidean distance among accessions in the EC.

Percentage of range ratios smaller than 0.70 \insertCitediwan_methods_1995EvaluateCore is computed as follows.

\mjtdeqn

RR\%_0.7 = \left ( \fracS_RR_0.7n \right ) \times 100RR\\\%_0.7 = \left ( \fracS_RR_0.7n \right ) \times 100RR%_0.7 = \left ( \fracS_RR_0.7n \right ) \times 100

Where, \mjseqnS_RR_0.7 is the number of traits with a range ratio smaller than 0.7 (\mjteqn\fracR_CS_iR_EC_i < 0.7\fracR_CS_iR_EC_i &lt; 0.7(R_CS_i / R_EC_i) < 0.7). \mjseqnR_CS_i is the range of the \mjseqnith trait in the CS, \mjseqnR_EC_i is the range of the \mjseqnith trait in the EC and \mjseqnn is the total number of traits.

Value

A data frame with the values of \mjteqnMD\%_HuMD\\\%_HuMD%_Hu, \mjteqnVD\%_HuVD\\\%_HuVD%_Hu, \mjteqnMD\%_KimMD\\\%_KimMD%_Kim, \mjteqnVD\%_KimVD\\\%_KimVD%_Kim and \mjteqn\overlinedD\%\overlinedD\\\%\overlinedD%.

References

\insertAllCited

See Also

snk.evaluate.core, snk.evaluate.core

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

percentdiff.evaluate.core(data = ec, names = "genotypes",
                          quantitative = quant, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.