scv.evaluate.core: Synthetic Variation Coefficient

View source: R/scv.evaluate.core.R

scv.evaluate.coreR Documentation

Synthetic Variation Coefficient

Description

Compute the Synthetic Variation Coefficient (\mjteqnCV\%CV\\\%CV%) \insertCitedong_exploration_1998,dong_genetic_2001EvaluateCore to compare quantitative traits of the entire collection (EC) and core set (CS).

Usage

scv.evaluate.core(data, names, quantitative, selected)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

Details

Synthetic Variation Coefficient (\mjteqnCV\%CV\\\%CV%) \insertCitedong_exploration_1998,dong_genetic_2001EvaluateCore is computed as follows for the core set (CS).

\mjtdeqn

CV(\%) = \left ( \frac1n \sum_i=1^n \fracSE_i\mu_i \right ) \times 100CV(\\\%) = \left ( \frac1n \sum_i=1^n \fracSE_j\mu_i \right ) \times 100CV(%) = \left ( \frac1n \sum_i=1^n \fracSE_j\mu_i \right ) \times 100

Where, \mjseqnSE_i is the standard error of the \mjseqnith trait, \mjseqn\mu_i is the mean of the \mjseqnith trait and \mjseqnn is the total number of traits.

Value

The Synthetic Variation Coefficient values for EC and CS

References

\insertAllCited

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                      function(x) factor(as.factor(x)))

scv.evaluate.core(data = ec, names = "genotypes",
                  quantitative = quant, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.