ttest.evaluate.core: Student's t Test

View source: R/ttest.evaluate.core.R

ttest.evaluate.coreR Documentation

Student's t Test

Description

Test difference between means of entire collection (EC) and core set (CS) for quantitative traits by Student's t test (in particular it's adaptation for comparison of groups with unequal variances known as Welch's two sample t-test) \insertCitestudent_probable_1908,welch_generalization_1947EvaluateCore.

Usage

ttest.evaluate.core(data, names, quantitative, selected)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

Value

Trait

The quantitative trait.

Count

The accession count (excluding missing data).

Df

The degrees of freedom for the test.

EC_Min

The minimum value of the trait in EC.

EC_Max

The maximum value of the trait in EC.

EC_Mean

The mean value of the trait in EC.

EC_SE

The standard error of the trait in EC.

CS_Min

The minimum value of the trait in CS.

CS_Max

The maximum value of the trait in CS.

CS_Mean

The mean value of the trait in CS.

CS_SE

The standard error of the trait in CS.

ttest_pvalue

The p value of the Student's t test for equality of means of EC and CS.

ttest_significance

The significance of the Student's t test for equality of means of EC and CS.

References

\insertAllCited

See Also

t.test

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

ttest.evaluate.core(data = ec, names = "genotypes",
                    quantitative = quant, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.