wilcox.evaluate.core: Wilcoxon Rank Sum Test

View source: R/wilcox.evaluate.core.R

wilcox.evaluate.coreR Documentation

Wilcoxon Rank Sum Test

Description

Compare the medians of quantitative traits between entire collection (EC) and core set (CS) by Wilcoxon rank sum test or Mann-Whitney-Wilcoxon test or Mann-Whitney U test \insertCitewilcoxon_individual_1945,mann_test_1947EvaluateCore.

Usage

wilcox.evaluate.core(data, names, quantitative, selected)

Arguments

data

The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data.

names

Name of column with the individual names as a character string.

quantitative

Name of columns with the quantitative traits as a character vector.

selected

Character vector with the names of individuals selected in core collection and present in the names column.

Value

Trait

The quantitative trait.

Count

The accession count (excluding missing data).

EC_Med

The median value of the trait in EC.

CS_Med

The median value of the trait in CS.

Wilcox_pvalue

The p value of the Wilcoxon test for equality of medians of EC and CS.

Wilcox_significance

The significance of the Wilcoxon test for equality of medians of EC and CS.

References

\insertAllCited

See Also

wilcox.test

Examples


data("cassava_CC")
data("cassava_EC")

ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL

core <- rownames(cassava_CC)

quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
           "ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
          "ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
          "PSTR")

ec[, qual] <- lapply(ec[, qual],
                     function(x) factor(as.factor(x)))

wilcox.evaluate.core(data = ec, names = "genotypes",
                     quantitative = quant, selected = core)


EvaluateCore documentation built on April 22, 2026, 9:07 a.m.