View source: R/vpf.evaluate.core.R
| vpf.evaluate.core | R Documentation |
Compute the Variance of Phenotypic Frequency (\mjseqnVPF) \insertCiteli_studies_2002EvaluateCore to compare qualitative traits between entire collection (EC) and core set (CS).
vpf.evaluate.core(data, names, qualitative, selected, na.omit = TRUE)
data |
The data as a data frame object. The data frame should possess one row per individual and columns with the individual names and multiple trait/character data. |
names |
Name of column with the individual names as a character string. |
qualitative |
Name of columns with the qualitative traits as a character vector. |
selected |
Character vector with the names of individuals selected in
core collection and present in the |
na.omit |
logical. If |
Variance of Phenotypic Frequency (\mjseqnVPF) \insertCiteli_studies_2002EvaluateCore is computed as follows.
\mjsdeqnVPF = \frac1n \sum_i=1^n\left ( \frac\sum_j=1^k (p_ij - \overlinep_i)^2k - 1 \right )
Where, \mjseqnp_ij denotes the proportion/fraction/frequency of accessions in the \mjseqnith phenotypic class for the \mjseqnith trait, \mjseqn\overlinep_i is the mean frequency of phenotypic classes for the \mjseqnith trait, \mjseqnk is the number of phenotypic classes for the \mjseqnith trait and \mjseqnn is the total number of traits.
The Variance of Phenotypic Frequency values for EC and CS.
data("cassava_CC")
data("cassava_EC")
ec <- cbind(genotypes = rownames(cassava_EC), cassava_EC)
ec$genotypes <- as.character(ec$genotypes)
rownames(ec) <- NULL
core <- rownames(cassava_CC)
quant <- c("NMSR", "TTRN", "TFWSR", "TTRW", "TFWSS", "TTSW", "TTPW", "AVPW",
"ARSR", "SRDM")
qual <- c("CUAL", "LNGS", "PTLC", "DSTA", "LFRT", "LBTEF", "CBTR", "NMLB",
"ANGB", "CUAL9M", "LVC9M", "TNPR9M", "PL9M", "STRP", "STRC",
"PSTR")
ec[, qual] <- lapply(ec[, qual],
function(x) factor(as.factor(x)))
vpf.evaluate.core(data = ec, names = "genotypes",
qualitative = qual, selected = core)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.